
//*****************************************************************************
//
// File Name	: 'test.c'
// Title		: SPI interface driven E0855-2 SED1530 graphic LCD
// Author		: Marc Meise
// Created		: Oktober 2007
// Version		: Beta
// Target MCU	: Atmel AVR series
//
//
// This code is distributed under the GNU Public License
// which can be found at http://www.gnu.org/licenses/gpl.txt
//
//*****************************************************************************

/*  Just a small Test-Program to demonstrate the functions of the E0855-2 SED1530 driver.
	The GLCD is connected via SPI.
	Development-Environment was a KANDA STK200 (I don't have the STK500) and an ATMega8535 with 8MHz.
	I assume that the demonstration/code should also work on the ATMega16/32 (DIP) without any modifikations after
	compilation with the AVR-GCC compiler.
	Please feel free to modify the driver to your own purpose.

	Disclaimer:I will not take any responsibility or what so ever for the functionality of the E0855-2 SED1530 driver.
	If you wreck anything - it's your own business...
	Modify this code and contribute freely.
*/

// PD7 is congured as a switch to step through the demo.
// I think that the command-functions are fairly self explanatory and are therefore not commented.

//Have fun!


#include <avr/io.h>
#include <avr/pgmspace.h>
#include <inttypes.h>
#include <SED1530.h>
#include <font.h>
#include <PICS.h>

unsigned char count=0;

char A[5][16] PROGMEM=
 	{"Out of Progmem:", 
	 "A PROGMEM String",
	 "out of an Array",
	 "->Seems to work!"
 	};

void pressbutton (void)
{
 while (!( PIND & (1<<PD7)))
 	{
 	delay();
	}
 while ( PIND & (1<<PD7)) ; 
 delay();
}

void Pagecount(void)
{
 SED_7segment(0,count);
 count++;
}

int main (void)
{
 DDRB=0xFF;
 PORTB=0xFF;
 DDRD=0x00;
 PORTD=0xFF;
 Init_SED1530();
 SED_contrast (15);
 SED_clear();
 SED_puts("Press PD7 to");
 SED_newline();
 SED_puts("step through the");
 SED_newline();
 SED_puts("demo of the GLCD");
 SED_set_XY(0,0);
 SED_puts("****************");
 SED_symbol(19,1);
 Pagecount();

while (1)
{
 pressbutton();
 SED_clear();
 SED_set_XY(3,10);
 SED_puts("This is a DEMO");
 SED_set_XY(2,15); 
 SED_puts("of the GLCD");
 SED_set_XY(1,27);
 SED_puts("E0855-2");
 SED_set_XY(0,27);
 SED_puts("*******");
 SED_symbol(63,1);
 Pagecount();

 pressbutton();
 SED_clear_page(0);
 SED_set_XY(0,1);
 SED_puts("A Number: ");
 SED_puts_num(32129);
 SED_symbol(36,1);
 SED_symbol(96,1);
 SED_symbol(95,1);
 SED_symbol(97,1);
 SED_symbol(98,1);
 SED_symbol(63,0);
 Pagecount();

 pressbutton();
 
 SED_clear();
 SED_set_XY(3,0);
 SED_puts_p(A[0]); // Read out of Progmem
 SED_set_XY(2,0);
 SED_puts_p(A[1]);
 SED_set_XY(1,0);
 SED_puts_p(A[2]);
 SED_set_XY(0,0);
 SED_puts_p(A[3]);
 SED_symbol(96,1);
 SED_symbol(95,1);
 SED_symbol(97,1);
 Pagecount();

 pressbutton();
 SED_showPIC (1);
 SED_symbol(98,0);
 SED_symbol(97,0);
 Pagecount();

 pressbutton();
 SED_showPIC (2);
 SED_symbol(36,0);
 SED_symbol(96,1);
 SED_symbol(95,0);
 SED_symbol(97,0);
 SED_symbol(98,0);
 SED_symbol(50,1);
 Pagecount();

 pressbutton();
 SED_clear();
 Pagecount();
 unsigned char x;
 for (x=0; x<=95; x++)
 	{
 	 SED_pixel(x, 0, 0b00000001);	 
	 SED_pixel(x, 3, 0b10000000);
	}
 for (x=0; x<=3; x++)
 	{
 	 SED_pixel(0, x, 0b11111111);	 
	 SED_pixel(95, x, 0b11111111);
	}

 SED_set_XY(2,8);
 SED_puts("Frame and Bar");
 SED_pixel(7, 1, 0b01111110);
 SED_pixel(86, 1,0b01111110);
 for(x=8; x<=85;x++)
 {
  SED_pixel(x, 1, 0b11111111);
 }

  for(x=9; x<=84;x++)
 {
  SED_pixel(x, 1, 0b10000001);
  delay();
 }
 SED_set_XY(2,8);
 SED_puts("  Press PD7  ");

 pressbutton();
 Pagecount();
 SED_symbol(19,1);
 SED_pixel(7, 1, 0x00);
 SED_pixel(86, 1,0x00);

 for(x=8; x<=85;x++)
 {
  SED_pixel(x, 1, 0b11111111);
  SED_pixel(x, 2, 0b11111111);
 }

  for(x=84; x>=50;x--)
 {
  SED_pixel(x, 1, 0b00000001);
  SED_pixel(x, 2, 0b10000000);
  delay();
 }

  for(x=9; x<=49;x++)
 {
  SED_pixel(x, 1, 0b00000001);
  SED_pixel(x, 2, 0b10000000);
  delay();
 }
 delay();
 delay();

 SED_clear();
 Pagecount();
 SED_puts("Going to sleep");
 SED_newline();
 SED_puts("Press PD7!");
 SED_newline();
 SED_puts("Press PD7 again");
 SED_newline();
 SED_puts("to wake-up!");
 SED_symbol(36,1);
 pressbutton();
 PORTB&=~(1<<PB6);
 SED_sleep();

 pressbutton();
 SED_wakeup();
 PORTB|=(1<<PB6);
 SED_clear();
 Pagecount();
 SED_puts("SED1530 Woke-up!");
 SED_newline();
 SED_newline();
 SED_puts("Press PD7 again");
 SED_newline();
 SED_puts("to continue demo");

 pressbutton();


 unsigned char smbl;
 SED_contrast (14);
 SED_clear();
 for (smbl=19; smbl<=99; smbl++)
 	{
	 SED_symbol(smbl,1);
	}
 SED_set_XY(2,0);
 SED_puts(" All Symbols ON ");
 SED_set_XY(0,74);
 SED_puts("END");
 count=1;

}
 return(0);
}


